package motorRedNeuronal;

/**Esta interfaz la implementan todas las clases que pueden formar parte de la red neuronal,
 * y define mtodos comunes para toda la red.*/
public interface INeurona
{
	/**Este mtodo calcula, si tiene datos suficientes, una salida a partir de la entrada.
	 * Antes de acabar, invoca este mismo mtodo en todas las INeurona conectadas a este objeto.
	 * No todos los elementos de la red proporcionan una implementacin de este mtodo,
	 * que en algunos casos est vaco.*/
	public void calcular (float in, INeurona origen);
	
	/**Este mtodo efectua el aprendizaje por retropropagacin, si el objeto tiene datos suficientes.
	 * Antes de acabar, invoca este mismo mtodo en todas las INeurona conectadas a este objeto.
	 * No todos los elementos de la red proporcionan una implementacin de este mtodo,
	 * que en algunos casos est vaco.*/
	public void retropropagar(float deltaAnterior, INeurona origen);
	
	/**Aade una INeurona como elemento entrante.
	 * No todos los elementos de la red proporcionan una implementacin de este mtodo,
	 * que en algunos casos est vaco.
	 */	
	public void addElementoEntrante(INeurona entrante);
	
	/**Aade una INeurona como elemento saliente.
	 * No todos los elementos de la red proporcionan una implementacin de este mtodo,
	 * que en algunos casos est vaco.
	 */	
	public void addElementoSaliente(INeurona saliente);

}
